[−][src]Function cl_traits::create_array
pub fn create_array<F, T, const N: usize>(cb: F) -> [T; N] where
F: FnMut(usize) -> T, Creates an array [T; N] where each array element T is returned by the cb call.
pub fn create_array<F, T, const N: usize>(cb: F) -> [T; N] where
F: FnMut(usize) -> T, Creates an array [T; N] where each array element T is returned by the cb call.