[−][src]Trait cl_traits::Capacity
See capacity for more information.
Associated Types
type Output
Output
Required methods
fn capacity(&self) -> Self::Output
The number of elements that the implementation is able to store, not necessary equal to its length.
Implementations on Foreign Types
impl<T> Capacity for Option<T>[src]
assert_eq!(cl_traits::Capacity::capacity(&Some(0)), 1);
Implementors
impl<'a, T> Capacity for &'a [T][src]
let structure = cl_traits::doc_tests::slice(); assert_eq!(cl_traits::Length::length(&structure), 3);
impl<'a, T> Capacity for &'a mut [T][src]
assert_eq!(cl_traits::Length::length(&&mut [1, 2, 3][..]), 3);
impl<A> Capacity for ArrayWrapper<A> where
A: Array, [src]
A: Array,
let mut structure = cl_traits::doc_tests::array_wrapper(); assert_eq!(cl_traits::Capacity::capacity(&structure), 3);