[][src]Trait cl_traits::Capacity

pub trait Capacity {
    type Output;
    fn capacity(&self) -> Self::Output;
}

See capacity for more information.

Associated Types

type Output

Output

Loading content...

Required methods

fn capacity(&self) -> Self::Output

The number of elements that the implementation is able to store, not necessary equal to its length.

Loading content...

Implementors

impl<'a, T> Capacity for &'a [T][src]

let structure = cl_traits::doc_tests::slice();
assert_eq!(cl_traits::Length::length(&structure), 3);

type Output = usize

impl<'a, T> Capacity for &'a mut [T][src]

assert_eq!(cl_traits::Length::length(&&mut [1, 2, 3][..]), 3);

type Output = usize

impl<A> Capacity for ArrayWrapper<A> where
    A: Array
[src]

let mut structure = cl_traits::doc_tests::array_wrapper();
assert_eq!(cl_traits::Capacity::capacity(&structure), 3);

type Output = usize

Loading content...